yakumo.neutron.v2.lbaas.pool.Manager

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module pool :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for LBaaS Pools in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for LBaaS Pools in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.lbaas.pool.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, lb_algorithm=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, protocol_port=`'``__UNDEF__``'`, listener=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, health_monitor=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, session_persistence=`'``__UNDEF__``'`) Create a load balancer pool | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``pool``'``
| _json_resources_key = ``'``pools``'``
| _url_resource_path = ``'``/v2.0/lbaas/pools``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, lb_algorithm=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, protocol_port=`'``__UNDEF__``'`, listener=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, health_monitor=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, session_persistence=`'``__UNDEF__``'`) | source code
Create a load balancer pool Parameters: `name` (str) - Pool name `description` (str) - Description `lb_algorithm` (str) - Load balance algorithm ('ROUND_ROBIN', 'LEAST_CONNECTIONS' or 'SOURCE_IP') `protocol` (str) - 'TCP', 'HTTP' or 'HTTPS' `protocol_port` (int) - Port number `subnet` (yakumo.neutron.v2.subnet.Resource) - Subnet object `is_enabled` (bool) - Whether the pool is enabled Returns: yakumo.neutron.v2.lbaas.pool.Resource Created pool Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('lb_algorithm', 'lb_algorithm', map
      per.Noop), ('protocol', 'protocol', mapper.Noop), ('listeners', 'liste
      ners', mapper.List(mapper.Resource('neutron.lbaas.listeners'))), ('mem
      bers', 'members', mapper.List(mapper.Resource('neutron.lbaas.member'))
      ), ('project', 'tenant_id', mapper.Resource('project')), ('healthmonit
      or', 'healthmonitor_id', mapper.Resource('neutron.lbaas.health_monitor
      ')), ('is_enabled', 'admin_state_up', mapper.Noop),]